@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2010-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2010-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -35,7 +35,7 @@ class Ldap : public SetupObject
     Q_OBJECT
 public:
     explicit Ldap(QObject *parent = nullptr);
-    ~Ldap();
+    ~Ldap() override;
     void create() override;
     void destroy() override;
     void edit();
